@@ -37,11 +37,12 @@ class FakeClusterTemplate(ClusterTemplate):
 class ShellTest(shell_test_base.TestCommandLineArgument):
 
     def _get_expected_args_list(self, limit=None, sort_dir=None,
-                                sort_key=None):
+                                sort_key=None, detail=False):
         expected_args = {}
         expected_args['limit'] = limit
         expected_args['sort_dir'] = sort_dir
         expected_args['sort_key'] = sort_key
+        expected_args['detail'] = detail
 
         return expected_args
 
@@ -57,7 +58,8 @@ class ShellTest(shell_test_base.TestCommandLineArgument):
                            tls_disabled=False, public=False,
                            master_lb_enabled=False, server_type='vm',
                            floating_ip_enabled=True,
-                           registry_enabled=False):
+                           registry_enabled=False,
+                           insecure_registry=None):
 
         expected_args = {}
         expected_args['image_id'] = image_id
@@ -84,6 +86,7 @@ class ShellTest(shell_test_base.TestCommandLineArgument):
         expected_args['server_type'] = server_type
         expected_args['floating_ip_enabled'] = floating_ip_enabled
         expected_args['registry_enabled'] = registry_enabled
+        expected_args['insecure_registry'] = insecure_registry
 
         return expected_args
 
@@ -462,6 +465,33 @@ class ShellTest(shell_test_base.TestCommandLineArgument):
                                     labels={'key1': 'val1', 'key2': 'val2'})
         mock_create.assert_called_with(**expected_args)
 
+    @mock.patch(
+        'magnumclient.v1.cluster_templates.ClusterTemplateManager.create')
+    def test_cluster_template_create_success_only_positional_name(self,
+                                                                  mock_create):
+        self._test_arg_success('cluster-template-create '
+                               'test '
+                               '--labels key1=val1,key2=val2 '
+                               '--keypair-id test_keypair '
+                               '--external-network-id test_net '
+                               '--image-id test_image '
+                               '--coe swarm '
+                               '--server-type vm')
+        expected_args = \
+            self._get_expected_args(name='test', image_id='test_image',
+                                    keypair_id='test_keypair', coe='swarm',
+                                    external_network_id='test_net',
+                                    server_type='vm',
+                                    labels={'key1': 'val1', 'key2': 'val2'})
+        mock_create.assert_called_with(**expected_args)
+
+    @mock.patch(
+        'magnumclient.v1.cluster_templates.ClusterTemplateManager.create')
+    def test_cluster_template_create_failure_duplicate_name(self, mock_create):
+        self._test_arg_failure('cluster-template-create '
+                               'foo --name test', self._mandatory_arg_error)
+        mock_create.assert_not_called()
+
     @mock.patch(
         'magnumclient.v1.cluster_templates.ClusterTemplateManager.create')
     def test_cluster_template_create_failure_few_arg(self, mock_create):
@@ -598,6 +628,14 @@ class ShellTest(shell_test_base.TestCommandLineArgument):
                                     external_network_id='public')
         mock_create.assert_called_with(**expected_args)
 
+        self._test_arg_failure(required_args + '--name foo',
+                               self._deprecated_warning)
+        expected_args = \
+            self._get_expected_args(image_id='test', coe='test',
+                                    name='foo',
+                                    external_network_id='public')
+        mock_create.assert_called_with(**expected_args)
+
     @mock.patch('magnumclient.v1.cluster_templates.ClusterTemplateManager.get')
     def test_cluster_template_show_success(self, mock_show):
         self._test_arg_success('cluster-template-show xxx')
@@ -693,6 +731,14 @@ class ShellTest(shell_test_base.TestCommandLineArgument):
         expected_args = self._get_expected_args_list(1, 'asc', 'uuid')
         mock_list.assert_called_once_with(**expected_args)
 
+    @mock.patch(
+        'magnumclient.v1.cluster_templates.ClusterTemplateManager.list')
+    def test_cluster_template_list_success_detailed(self, mock_list):
+        self._test_arg_success('cluster-template-list '
+                               '--detail')
+        expected_args = self._get_expected_args_list(detail=True)
+        mock_list.assert_called_once_with(**expected_args)
+
     @mock.patch(
         'magnumclient.v1.cluster_templates.ClusterTemplateManager.list')
     def test_cluster_template_list_ignored_duplicated_field(self, mock_list):
